@@ -1,10 +1,7 @@
 
 # load data with missings
-# testM <- import_spss(file = "tests/testthat/helper_spss_missings.sav")
-# load(file = "tests/testthat/helper_data.rda")
-# testM <- import_spss("tests/testthat/helper_spss_missings.sav")
-testM <- import_spss("helper_spss_missings.sav")
-load(file = "helper_data.rda")
+testM <- import_spss(test_path("helper_spss_missings.sav"))
+load(file = test_path("helper_data.rda"))
 
 control_caching <- FALSE
 
@@ -21,7 +18,7 @@ test_that("Warnings and errors for Extract Data",  {
   w <- capture_warnings(extractData(testM))
   expect_equal(w[[1]], "Variable VAR1 is partially labeled. Value labels will be dropped for this variable.\nLabeled values are: 1")
   expect_equal(w[[2]], "Variable VAR2 is partially labeled. Value labels will be dropped for this variable.\nLabeled values are: -96")
-  expect_error(extractData(testM, convertLabels = "integer"), "Argument convertLabels incorrectly specified.")
+  expect_error(extractData(testM, convertLabels = "integer"))
 })
 
 test_that("Extract data", {
@@ -50,6 +47,30 @@ test_that("Extract data for strings into factors", {
   expect_equal(out$Var_char2, as.factor(c("b_value", "b_value", "b_value", "b_value")))
 })
 
+test_that("Extract data into factor with duplicate value labels", {
+  testM3 <- changeValLabels(testM2, varName = "VAR1", value = "2", valLabel = "One")
+  testM3$dat$VAR1 <- testM3$dat$VAR1
+  outW <- capture_warnings(out <- extractData(testM3, convertLabels = "factor",
+                                              convertVariables = "VAR1", convertMiss = TRUE))
+
+  expect_equal(outW[2],
+               paste0("Duplicate value label in variable VAR1. The following values (see value column) will be recoded into the same value label (see valLabel column):\n",
+                      eatTools::print_and_capture(testM3$labels[testM3$labels$varName == "VAR1" & testM3$labels$valLabel == "One", ])))
+  expect_equal(class(out$VAR1), "factor")
+  out_factor <- factor(c("One", NA, NA, "One"))
+  attr(out_factor, "label") <- "Variable 1"
+  expect_equal(out$VAR1, out_factor)
+
+  suppressWarnings(out2 <- extractData(testM3, convertLabels = "factor",
+                                       convertVariables = "VAR1", convertMiss = FALSE))
+
+  expect_equal(class(out2$VAR1), "factor")
+  out_factor2 <- factor(c("One", "By design", "Omission", "One"))
+  attr(out_factor2, "label") <- "Variable 1"
+  expect_equal(out2$VAR1, out_factor2)
+})
+
+
 test_that("char2fac", {
   df <- data.frame(v1 = factor(c("z", "a", "b"), levels = c("z", "a", "b")),
                    stringsAsFactors = TRUE)
@@ -135,6 +156,14 @@ test_that("Correct behavior if not all value labels in actual values", {
   expect_equal(as.numeric(dat$v1), c(1, 2, 1))
 })
 
+test_that("Correct behavior if values are being recoded into then to be recoded values", {
+  dat <- data.frame(v1 = c(1, 2, 98, 99))
+  gads <- import_DF(dat)
+  gads2 <- changeValLabels(gads, "v1", value = c(1, 2, 98, 99),
+                           valLabel = c(98, 99, "missing 1", "missing 2"))
+  out <- extractData(gads2)
+  expect_equal(out[[1]], c(98, 99, "missing 1", "missing 2"))
+})
 
 mixed_values <- new_GADSdat(dat = data.frame(x = 0, y = 1, stringsAsFactors = FALSE),
                             labels = data.frame(varName = c("x", "y"),
@@ -178,8 +207,8 @@ test_that("ExtractData with some variables labels applied to (convertVariables a
 })
 
 test_that("Extract data trend GADS", {
-  # trend_gads <- getTrendGADS(filePaths = c("tests/testthat/helper_dataBase.db", "tests/testthat/helper_dataBase_uniqueVar.db"), years = c(2012, 2018), fast = FALSE)
-  trend_gads <- suppressWarnings(getTrendGADS(filePaths = c("helper_dataBase.db", "helper_dataBase_uniqueVar.db"),
+  trend_gads <- suppressWarnings(getTrendGADS(filePaths =
+                                                test_path(c("helper_dataBase.db", "helper_dataBase_uniqueVar.db")),
                                               years = c(2012, 2018), fast = FALSE, verbose = FALSE))
   out <- extractData(trend_gads)
   expect_equal(dim(out), c(6, 5))
@@ -190,6 +219,7 @@ test_that("Extract data trend GADS", {
 
   ## convertVariables if some variables are not in both GADS
   out2 <- extractData(trend_gads, convertVariables = "V3")
+  out2 <- extractData2(trend_gads, labels2character = "V3")
   expect_equal(out, out2)
 })
 
@@ -209,9 +239,11 @@ test_that("Extract data trend GADS 3 MPs", {
 
 ### with linking errors
 test_that("with linking errors present", {
-  # out <- getTrendGADSOld(filePath1 = "tests/testthat/helper_comp.db", filePath2 = "tests/testthat/helper_comp2.db", years = c(2012, 2018), lePath = "tests/testthat/helper_le.db", fast = FALSE, vSelect = c("ID", "PV"))
-  out <- getTrendGADSOld(filePath1 = "helper_comp.db", filePath2 = "helper_comp2.db", years = c(2012, 2018),
-                         lePath = "helper_le.db", fast = control_caching, vSelect = c("ID", "PV"))
+  out <- getTrendGADSOld(filePath1 = test_path("helper_comp.db"),
+                         filePath2 = test_path("helper_comp2.db"),
+                         years = c(2012, 2018),
+                         lePath = test_path("helper_le.db"),
+                         fast = control_caching, vSelect = c("ID", "PV"))
   expect_error(dat <- extractData(out),
                "Linking errors are no longer supported by extractData. Use extractDataOld() instead.", fixed = TRUE)
 })
